@@ -1,3 +1,4 @@
+import datetime
 import time
 
 import yaml
@@ -123,7 +124,8 @@ class TimeoutSampler:
         timeout_watch = TimeoutWatch(timeout=self.wait_timeout)
         if self.print_log:
             LOGGER.info(
-                f"Waiting for {self.wait_timeout} seconds, retry every"
+                f"Waiting for {self.wait_timeout} seconds"
+                f" [{datetime.timedelta(seconds=self.wait_timeout)}], retry every"
                 f" {self.sleep} seconds. ({self._func_log})"
             )
 
@@ -146,7 +148,7 @@ class TimeoutSampler:
 
             finally:
                 if self.elapsed_time and self.print_log:
-                    LOGGER.info(f"Elapsed time: {self.elapsed_time}")
+                    LOGGER.info(f"Elapsed time: {self.elapsed_time} [{datetime.timedelta(seconds=self.elapsed_time)}]")
 
         raise TimeoutExpiredError(self._get_exception_log(exp=last_exp))
 
@@ -181,9 +183,7 @@ class TimeoutSampler:
         for entry in self.exceptions_dict:
             if isinstance(exp, entry):  # Check inheritance for raised exception
                 exception_messages = self.exceptions_dict.get(entry)
-                if self._is_exception_matched(
-                    exp=exp, exception_messages=exception_messages
-                ):
+                if self._is_exception_matched(exp=exp, exception_messages=exception_messages):
                     return False
 
         return True
@@ -219,9 +219,7 @@ class TimeoutWatch:
         return self.start_time + self.timeout - time.time()
 
 
-def skip_existing_resource_creation_teardown(
-    resource, export_str, user_exported_args, check_exists=True
-):
+def skip_existing_resource_creation_teardown(resource, export_str, user_exported_args, check_exists=True):
     """
     Args:
         resource (Resource): Resource to match against.
@@ -264,10 +262,7 @@ def skip_existing_resource_creation_teardown(
             )
 
         for _name, _namespace in _resource_args.items():
-            if resource_name == _name and (
-                resource_namespace == _namespace
-                or not (resource_namespace and _namespace)
-            ):
+            if resource_name == _name and (resource_namespace == _namespace or not (resource_namespace and _namespace)):
                 return _return_resource(
                     _resource=resource,
                     _check_exists=check_exists,
